@@ -17,7 +17,10 @@
  */
 
 
-if (strlen($outputdir) == 0 || $g_alldatabases) {
+if (strlen($outputdir) > 0 && $g_alldatabases) {
+  $outputdir = $outputdir.'/'.$PGDATABASE.'_snap_'.date('Ymd');
+}
+else if (strlen($outputdir) == 0 || $g_alldatabases) {
   $outputdir = $PGDATABASE.'_snap_'.date('Ymd');
 }
 
@@ -46,7 +49,7 @@ if (file_exists($outputdir)) {
     }
   }
 } else {
-  mkdir($outputdir);
+  mkdir($outputdir, 0700, true);
 }
 
 echo "Connecting to $PGDATABASE database...\n";
@@ -63,7 +66,17 @@ if ($row = pg_fetch_array($rows)) {
   $g_version = $tmp[0].$tmp[1];
 }
 
-if (!$queriesinlogs) {
+$query = 'SELECT rolsuper FROM pg_roles WHERE rolname=current_user';
+$rows = pg_query($connection, $query);
+if (!$rows) {
+  echo "An error occured.\n";
+  exit;
+}
+if ($row = pg_fetch_array($rows)) {
+  $g_superuser = $row['rolsuper'] == 't';
+}
+
+if (!$queriesinlogs && $g_superuser) {
   if ($g_version == 74) {
     $query = "SET log_statement TO off; SET log_duration TO off; SET log_min_duration_statement TO -1;";
   } else {
@@ -76,6 +89,8 @@ echo "Adding some HTML files...\n";
 // javascript
 copy($PGSNAP_ROOT_PATH.'external/jquery-1.2.3.js',
      $outputdir.'/jquery-1.2.3.js');
+copy($PGSNAP_ROOT_PATH.'external/jquery.tablesorter.js',
+     $outputdir.'/jquery.tablesorter.js');
 // css
 copy($PGSNAP_ROOT_PATH.'template/fixed.css', $outputdir.'/fixed.css');
 copy($PGSNAP_ROOT_PATH.'template/global.css', $outputdir.'/global.css');
@@ -186,6 +201,9 @@ if ($g_version > '74') {
   include 'lib/tblspc1.php';
 }
 include 'lib/largeobjects.php';
+if ($g_superuser && $g_version > '80') {
+  include 'lib/xlog.php';
+}
 
 echo "Getting Database Informations...\n";
 include 'lib/schemas.php';
@@ -214,6 +232,9 @@ include 'lib/views.php';
 include 'lib/sequences.php';
 include 'lib/sequences2.php';
 include 'lib/indexes.php';
+if ($g_flashexists && $g_version > '80') {
+  include 'lib/graph_indexsize.php';
+}
 if ($g_version > '82') {
   include 'lib/uselessindexes.php';
 }
@@ -230,11 +251,17 @@ if ($g_version > '80') {
 }
 include 'lib/languages.php';
 include 'lib/functions.php';
+if ($g_version >= '91') {
+  include 'lib/extensions.php';
+}
 
 echo "Getting Current Activities Informations...\n";
 include 'lib/sessionsinfo.php';
 include 'lib/activities.php';
 include 'lib/nonidleprocesses.php';
+if ($g_version >= '91') {
+  include 'lib/replication.php';
+}
 if ($g_version >= '82') {
   include 'lib/cursors.php';
   include 'lib/preparedstatements.php';
@@ -260,6 +287,9 @@ if ((array_key_exists('stats_block_level', $g_settings)
   include 'lib/cachehitratio.php';
 }
 include 'lib/stat_databases.php';
+if ($g_version >= '91') {
+  include 'lib/stat_databases_conflicts.php';
+}
 include 'lib/stat_tables.php';
 include 'lib/statio_tables.php';
 if ($g_version >= '82') {
