@@ -50,7 +50,8 @@ if (!$rows) {
 
 $buffer .= '<div class="tblBasic">
 
-<table border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
+<table id="myTable" border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
+<thead>
 <tr>
   <th class="colFirst">Schema name</th>
   <th class="colMid">Table name</th>
@@ -58,6 +59,8 @@ $buffer .= '<div class="tblBasic">
   <th class="colMid">Blocks Read</th>
   <th class="colLast">Blocks Hit</th>
 </tr>
+</thead>
+<tbody>
 ';
 
 while ($row = pg_fetch_array($rows)) {
@@ -70,7 +73,8 @@ $buffer .= tr($row['schemaname'])."
 </tr>";
 }
 
-$buffer .= '</table>
+$buffer .= '</tbody>
+</table>
 </div>
 ';
 
