@@ -55,7 +55,8 @@ if (!$rows) {
 
 $buffer .= '<div class="tblBasic">
 
-<table border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
+<table id="myTable" border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
+<thead>
 <tr>
   <th class="colFirst">Schema</th>
   <th class="colMid">Table</th>
@@ -68,6 +69,8 @@ $buffer .= '<div class="tblBasic">
   <th class="colMid">Toast Index Blocks Read</th>
   <th class="colMid">Toast Index Blocks Hit</th>
 </tr>
+</thead>
+<tbody>
 ';
 
 while ($row = pg_fetch_array($rows)) {
@@ -85,7 +88,8 @@ $buffer .= tr($row['schemaname'])."
 </tr>";
 }
 
-$buffer .= '</table>
+$buffer .= '</tbody>
+</table>
 </div>
 ';
 
