@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -30,7 +30,20 @@ $buffer = $navigate_general.'
 </tr>
 ';
 
-$query = "SELECT 'PostgreSQL' AS product, version() AS version;";
+$query = "SELECT 'PostgreSQL' AS product, version() AS version";
+if ($g_version >= 81) {
+    $query .= ", pg_postmaster_start_time() AS starttime, ";
+    if ($g_version >= 84) {
+	    $query .= "pg_conf_load_time()";
+    } else {
+	    $query .= "'unavailable'";
+    }
+    $query .= " AS reloadtime";
+    if ($g_version >= 90) {
+		$query .= ", pg_is_in_recovery() AS recovery,
+  pg_last_xlog_receive_location(), pg_last_xlog_replay_location() ";
+	}
+}
 
 $rows = pg_query($connection, $query);
 if (!$rows) {
@@ -75,9 +88,73 @@ if ($g_fsmrelations) {
 ';
 }
 
+// check a few other contrib modules by functions
+$functions = array(
+    'adminpack'          => 'pg_file_write',
+    'btree_gin'          => 'gin_btree_consistent',
+    'btree_gist'         => 'gbtreekey4_in',
+    'citext'             => 'citext_smaller',
+    'cube'               => 'cube_distance',
+    'dblink'             => 'dblink_connect',
+    'dict_int'           => 'dintdict_lexize',
+    'dict_xsyn'          => 'dxsyn_lexize',
+    'earthdistance'      => 'earth_distance',
+    'fuzzystrmatch'      => 'dmetaphone_alt',
+    'hstore'             => 'hstore_out',
+    'intarray'           => 'intarray_del_elem',
+    'isn'                => 'isbn13_in',
+    'lo'                 => 'lo_manage',
+    'ltree'              => 'ltree2text',
+    'pageinspect'        => 'heap_page_items',
+    'pgcrypto'           => 'gen_salt',
+    'pg_row_locks'       => 'pgrowlocks',
+    'pg_stat_statements' => 'pg_stat_statements_reset',
+    'pg_trgm'            => 'show_trgm',
+    'seg'                => 'seg_over_left',
+    'sslinfo'            => 'ssl_client_cert_present',
+    'tablefunc'          => 'crosstab4',
+    'tsearch2'           => 'to_tsvector',
+    'uuid'               => 'uuid_ns_x500',
+    'xml2'               => 'xslt_process'
+);
+
+foreach ($functions as $module => $function) {
+  $fquery = "SELECT 1 FROM pg_proc WHERE proname = '$function'";
+  $frows = pg_query($connection, $fquery);
+  if (!$frows) {
+    echo "An error occured.\n";
+    exit;
+  }
+
+  if (pg_num_rows($frows) == 1) {
+    $buffer .= tr().'
+  <td>'.$module.'</td>
+  <td><i>Contrib module</i></td>
+</tr>
+';
+  }
+  pg_free_result($frows);
+}
+
 $buffer .= '</table>
+';
+
+if ($g_version >= 81) {
+  $buffer .= '<div class="tblBasic">
+
+<table border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
+<tr>
+  <th class="colFirst">Started on</th>
+  <th class="colLast">Conf. reloaded on</th>
+</tr>
+<tr>
+  <td>'.$row['starttime'].'</td>
+  <td>'.$row['reloadtime'].'</td>
+</tr>
+</table>
 </div>
 ';
+}
 
 $buffer .= '<h1>Primary options</h1>
 <div class="tblBasic">
@@ -89,6 +166,18 @@ $buffer .= '<h1>Primary options</h1>
 </tr>
 ';
 
+if ($g_version >= 90) {
+  $buffer .= tr().'
+  <td><a href="param.html#Write-AheadLogSettings">In Recovery</a></td>
+  <td>'.$image[$row['recovery']];
+  if ($row['recovery'] == 't') {
+	  $buffer .= ' ('.$row['pg_last_xlog_receive_location'].' / '.$row['pg_last_xlog_replay_location'].')';
+  }
+  $buffer .= '</td>
+</tr>
+';
+}
+
 if (array_key_exists('autovacuum', $g_settings)) {
   $buffer .= tr().'
   <td><a href="param.html#Autovacuum">Autovacuum</a></td>
